# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

apiCaPath: Optional[str]
"""
The path to a Linode API CA file to trust.
"""

apiVersion: Optional[str]
"""
The version of Linode API.
"""

configPath: Optional[str]
"""
The path to the Linode config file to use. (default `~/.config/linode`)
"""

configProfile: Optional[str]
"""
The Linode config profile to use. (default `default`)
"""

disableInternalCache: Optional[bool]
"""
Disable the internal caching system that backs certain Linode API requests.
"""

eventPollMs: Optional[int]
"""
The rate in milliseconds to poll for events.
"""

lkeEventPollMs: Optional[int]
"""
The rate in milliseconds to poll for LKE events.
"""

lkeNodeReadyPollMs: Optional[int]
"""
The rate in milliseconds to poll for an LKE node to be ready.
"""

maxRetryDelayMs: Optional[int]
"""
Maximum delay in milliseconds before retrying a request.
"""

minRetryDelayMs: Optional[int]
"""
Minimum delay in milliseconds before retrying a request.
"""

objAccessKey: Optional[str]
"""
The access key to be used in ObjectStorageBucket and linode_object_storage_object.
"""

objBucketForceDelete: Optional[bool]
"""
If true, when deleting a ObjectStorageBucket any objects and versions will be force deleted.
"""

objSecretKey: Optional[str]
"""
The secret key to be used in ObjectStorageBucket and linode_object_storage_object.
"""

objUseTempKeys: Optional[bool]
"""
If true, temporary object keys will be created implicitly at apply-time for the ObjectStorageObject and
linode_object_sorage_bucket resource.
"""

skipImplicitReboots: Optional[bool]
"""
If true, Linode Instances will not be rebooted on config and interface changes.
"""

skipInstanceDeletePoll: Optional[bool]
"""
Skip waiting for a Instance resource to finish deleting.
"""

skipInstanceReadyPoll: Optional[bool]
"""
Skip waiting for a Instance resource to be running.
"""

token: Optional[str]
"""
The token that allows you access to your Linode account
"""

uaPrefix: Optional[str]
"""
An HTTP User-Agent Prefix to prepend in API requests.
"""

url: Optional[str]
"""
The HTTP(S) API address of the Linode API to use.
"""

